@@ -35,6 +35,10 @@ $desc	   = sanity_check_array($_REQUEST["desc"]);
 $random	   = sanity_check_number($_REQUEST["random"]);
 $edit	   = sanity_check($_REQUEST["edit"]);
 
+if ($thumbs > 1) {
+	$THUMB_COLUMNS = $thumbs;
+}
+
 $EDIT = 0;
 if ((strlen($EDIT_PW) > 0) && ($edit == $EDIT_PW)) {
 	$EDIT = 1;
@@ -292,6 +296,7 @@ body {
 }
 </style>
 <title>$TITLE</title>
+<link rel='shortcut icon' href='/pictor/favicon.ico' type='image/x-icon'>
 </head>
 	");
 	if ($body == 1) {
@@ -637,7 +642,7 @@ function get_next_link($album, $width, $pictures, $currentindex, $slideshow) {
 	if ($slideshow > 0) {
 		print("<meta http-equiv='refresh' content='$slideshow;url=$url&slideshow=$slideshow'>\n");
 	}
-	$next = "<table border=0><tr><td bgcolor=white><a href='$url'><b>Next &gt;</b></a></td></tr></table>";
+	$next = "<table border=0><tr><td bgcolor=white><a href='$url'><b>Next <img src=next.png></b></a></td></tr></table>";
 	return $next;
 }
 
@@ -645,7 +650,7 @@ function get_back_link($album, $width, $pictures, $currentindex) {
 	if ($currentindex != 0) {
 		$back = $pictures[$currentindex-1];
 		$url = "?album=" . urlencode($album) . "&picture=" . urlencode($back) . "&width=$width";
-		$back = "<table border=0><tr><td bgcolor=white><a href='$url'><b>&lt; Back</b></a></td></tr></table>";
+		$back = "<table border=0><tr><td bgcolor=white><a href='$url'><b><img src=prev.png> Back</b></a></td></tr></table>";
 		return $back;
 	} else {
 		return "&nbsp;";
@@ -726,7 +731,7 @@ function print_upper_banner($album, $description, $width) {
                    <table border=0 cellpadding=0 cellspacing=0 align=center width=100%>
 		    <tr>
 		     <td colspan=3>
-		      <p align=center><big><b>$TITLE</b></big><br><b>$descr</b></p>
+		      <p align=center><b>$descr</b></p>
 		     </td>
 		    </tr>
 	");
